==> ukelli-ui-3.0.0.tgz: package/core/record-render/mapper-filter.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
/* eslint-disable eqeqeq */
/* eslint-disable no-var */
/* eslint-disable vars-on-top */
import React from 'react';
import { HasValue, DateFormat, MoneyFormat, IsFunc, Call } from 'basic-helper';
import { ToolTip } from '../tooltip';
import { Label } from '../label';
import Dropdown from '../selector/dropdown-menu';
import { UkeComponent } from '../utils/uke-component';
var excludeKey = function (target, keys) {
    var res = Object.assign({}, target);
    keys.forEach(function (item) {
        res[item] = '';
    });
    return res;
};
var MapperFilter = /** @class */ (function (_super) {
    __extends(MapperFilter, _super);
    function MapperFilter() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        /** 可以覆盖的 excludeKeys */
        _this.excludeKeys = ['records', 'keyMapper', 'checkedOverlay', 'whenCheckAction'];
        _this.sortIgnores = [];
        _this.selectorCache = {};
        _this.scrollX = 0;
        _this.scrollY = 0;
        _this.isInFixedTable = function (key) {
            var _a = _this.props, fixedRightKeys = _a.fixedRightKeys, fixedLeftKeys = _a.fixedLeftKeys;
            var isInFixTable = (Array.isArray(fixedRightKeys) && Array.isArray(fixedLeftKeys))
                && (fixedLeftKeys.concat(fixedRightKeys).indexOf(key) !== -1);
            return isInFixTable;
        };
        /**
         * mapperFilter 字段过滤器处理顺序
         *
         * 1. date || datetime || money || abvMoney
         * 2. labels && namesMapper
         * 3. filter
         */
        _this.mapperFilter = function (mapper, record, rowIdx) {
            var originContent = record[mapper.key];
            var currContent = originContent;
            if (!HasValue(currContent)) {
                currContent = currContent || '-';
            }
            var date = mapper.date, datetime = mapper.datetime, money = mapper.money, abvMoney = mapper.abvMoney, namesMapper = mapper.namesMapper, labels = mapper.labels, filter = mapper.filter;
            var contentResult = currContent;
            /** 互相冲突的字段，即不可能同时为 datetime 也是 money 的 */
            switch (true) {
                case !!date:
                case !!datetime:
                    var format = "YYYY-MM-DD" + (date ? '' : ' hh:mm:ss');
                    contentResult = /0001/.test(currContent) ? '-' : DateFormat(currContent, format);
                    break;
                case !!money:
                case !!abvMoney:
                    contentResult = MoneyFormat(contentResult);
                    if (abvMoney)
                        contentResult = contentResult.replace('-', '');
                    break;
            }
            /** 并不冲突的，需要流式处理，swtich case 只能互相冲突的情况 */
            if (namesMapper) {
                currContent = namesMapper[currContent] || currContent || '';
                contentResult = currContent;
            }
            if (labels) {
                var labelColor = labels[originContent];
                contentResult = labelColor ? (React.createElement(Label, { color: labelColor, text: currContent })) : currContent;
            }
            if (IsFunc(filter)) {
                contentResult = filter(contentResult, record, mapper, rowIdx);
            }
            return contentResult;
        };
        return _this;
    }
    MapperFilter.prototype.shouldComponentUpdate = function (nextProps, nextState, nextContext) {
        /** 渲染前做自定义的数据对比，提升表格渲染的效率 */
        var _thisProps = excludeKey(this.props, this.excludeKeys);
        var _nextProps = excludeKey(nextProps, this.excludeKeys);
        var _a = this.props, keyMapper = _a.keyMapper, records = _a.records;
        var isStateChange = this.state != nextState;
        var isPropsChange = JSON.stringify(_thisProps) !== JSON.stringify(_nextProps);
        var isKeyMapperChange = keyMapper != nextProps.keyMapper;
        var isRecordsChange = records != nextProps.records;
        // const isCheckedItemsChange = this.state.checkedItems != nextState.checkedItems;
        if (isRecordsChange && this.onChangeRecords) {
            this.onChangeRecords();
        }
        return isStateChange || isPropsChange || isKeyMapperChange || isRecordsChange;
    };
    MapperFilter.prototype.titleFilter = function (item, idx) {
        var _this = this;
        var _a = item, title = _a.title, key = _a.key, tips = _a.tips, fixed = _a.fixed;
        var titleDOM;
        if (typeof title === 'function') {
            titleDOM = title(item, idx);
        }
        else if (typeof title === 'object') {
            switch (title.type) {
                case 'selector':
                    var _b = title, _c = _b.outside, outside = _c === void 0 ? true : _c, _d = _b.defaultTitle, defaultTitle = _d === void 0 ? this.$T(key) : _d, _e = _b.invalidTip, invalidTip = _e === void 0 ? this.$T_UKE('默认') : _e, _f = _b.cancelTitle, cancelTitle = _f === void 0 ? this.$T_UKE('默认') : _f, _g = _b.ref, ref_1 = _g === void 0 ? key : _g, onChange_1 = _b.onChange, other = __rest(_b, ["outside", "defaultTitle", "invalidTip", "cancelTitle", "ref", "onChange"]);
                    var isInFixTable = this.isInFixedTable(key) || !!fixed;
                    titleDOM = (React.createElement(Dropdown, __assign({}, other, { withInput: false, onChange: function (val) {
                            var _a;
                            var emitVal = (_a = {},
                                _a[ref_1] = val,
                                _a);
                            Call(onChange_1, emitVal);
                            Call(_this.props.onChange, emitVal, title);
                        }, scrollX: isInFixTable ? 0 : this.scrollX, 
                        // scrollY={this.scrollY}
                        outside: outside, defaultTitle: defaultTitle, invalidTip: invalidTip, cancelTitle: cancelTitle })));
                    if (this.sortIgnores.indexOf(key) === -1)
                        this.sortIgnores.push(key);
                    break;
            }
        }
        else {
            titleDOM = this.$T(title || key);
        }
        var tipsDOM = tips ? (React.createElement(ToolTip, { n: "question", s: "r", title: tips })) : null;
        return (React.createElement("div", null,
            tipsDOM,
            titleDOM));
    };
    return MapperFilter;
}(UkeComponent));
export default MapperFilter;
export { excludeKey };

==> ukelli-ui-3.1.0.tgz: package/core/record-render/mapper-filter.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
/* eslint-disable eqeqeq */
/* eslint-disable no-var */
/* eslint-disable vars-on-top */
import React from 'react';
import { HasValue, DateFormat, MoneyFormat, IsFunc, Call, DebounceClass } from 'basic-helper';
import { ToolTip } from '../tooltip';
import { Label } from '../label';
import Dropdown from '../selector/dropdown-menu';
import { UkeComponent } from '../utils/uke-component';
var delayExec = new DebounceClass();
var excludeKey = function (target, keys) {
    var res = Object.assign({}, target);
    keys.forEach(function (item) {
        res[item] = '';
    });
    return res;
};
var MapperFilter = /** @class */ (function (_super) {
    __extends(MapperFilter, _super);
    function MapperFilter() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        /** 可以覆盖的 excludeKeys */
        _this.excludeKeys = ['columns', 'records', 'keyMapper', 'checkedOverlay', 'whenCheckAction'];
        _this.sortIgnores = [];
        _this.selectorCache = {};
        _this.scrollX = 0;
        _this.scrollY = 0;
        _this.isInFixedTable = function (key) {
            var _a = _this.props, fixedRightKeys = _a.fixedRightKeys, fixedLeftKeys = _a.fixedLeftKeys;
            var isInFixTable = (Array.isArray(fixedRightKeys) && Array.isArray(fixedLeftKeys))
                && (fixedLeftKeys.concat(fixedRightKeys).indexOf(key) !== -1);
            return isInFixTable;
        };
        /**
         * mapperFilter 字段过滤器处理顺序
         *
         * 1. date || datetime || money || abvMoney
         * 2. labels && namesMapper
         * 3. filter
         */
        _this.mapperFilter = function (mapper, record, rowIdx) {
            var originContent = record[mapper.key];
            var currContent = originContent;
            if (!HasValue(currContent)) {
                currContent = currContent || '-';
            }
            var date = mapper.date, datetime = mapper.datetime, money = mapper.money, abvMoney = mapper.abvMoney, namesMapper = mapper.namesMapper, labels = mapper.labels, filter = mapper.filter;
            var contentResult = currContent;
            /** 互相冲突的字段，即不可能同时为 datetime 也是 money 的 */
            switch (true) {
                case !!date:
                case !!datetime:
                    var format = "YYYY-MM-DD" + (date ? '' : ' hh:mm:ss');
                    contentResult = /0001/.test(currContent) ? '-' : DateFormat(currContent, format);
                    break;
                case !!money:
                case !!abvMoney:
                    contentResult = MoneyFormat(contentResult);
                    if (abvMoney)
                        contentResult = contentResult.replace('-', '');
                    break;
            }
            /** 并不冲突的，需要流式处理，swtich case 只能互相冲突的情况 */
            if (namesMapper) {
                currContent = namesMapper[currContent] || currContent || '';
                contentResult = currContent;
            }
            if (labels) {
                var labelColor = labels[originContent];
                contentResult = labelColor ? (React.createElement(Label, { color: labelColor, text: currContent })) : currContent;
            }
            if (IsFunc(filter)) {
                contentResult = filter(contentResult, record, mapper, rowIdx);
            }
            return contentResult;
        };
        return _this;
    }
    MapperFilter.prototype.shouldComponentUpdate = function (nextProps, nextState, nextContext) {
        /** 渲染前做自定义的数据对比，提升表格渲染的效率 */
        var _thisProps = excludeKey(this.props, this.excludeKeys);
        var _nextProps = excludeKey(nextProps, this.excludeKeys);
        var records = this.props.records;
        var columns = this.getColumns();
        var isStateChange = this.state != nextState;
        var isPropsChange = JSON.stringify(_thisProps) !== JSON.stringify(_nextProps);
        var isKeyMapperChange = columns != nextProps.columns;
        var isRecordsChange = records != nextProps.records;
        // const isCheckedItemsChange = this.state.checkedItems != nextState.checkedItems;
        if (isRecordsChange && this.onChangeRecords) {
            this.onChangeRecords();
        }
        return isStateChange || isPropsChange || isKeyMapperChange || isRecordsChange;
    };
    MapperFilter.prototype.getColumns = function () {
        var _a = this.props, columns = _a.columns, keyMapper = _a.keyMapper;
        if (keyMapper) {
            delayExec.exec(function () {
                console.log('请将 keyMapper 重命名为 columns');
            }, 300);
        }
        return columns || keyMapper || [];
    };
    MapperFilter.prototype.titleFilter = function (item, idx) {
        var _this = this;
        var _a = item, title = _a.title, key = _a.key, tips = _a.tips, fixed = _a.fixed;
        var titleDOM;
        if (typeof title === 'function') {
            titleDOM = title(item, idx);
        }
        else if (typeof title === 'object') {
            switch (title.type) {
                case 'selector':
                    var _b = title, _c = _b.outside, outside = _c === void 0 ? true : _c, _d = _b.defaultTitle, defaultTitle = _d === void 0 ? this.$T(key) : _d, _e = _b.invalidTip, invalidTip = _e === void 0 ? this.$T_UKE('默认') : _e, _f = _b.cancelTitle, cancelTitle = _f === void 0 ? this.$T_UKE('默认') : _f, _g = _b.ref, ref_1 = _g === void 0 ? key : _g, onChange_1 = _b.onChange, other = __rest(_b, ["outside", "defaultTitle", "invalidTip", "cancelTitle", "ref", "onChange"]);
                    var isInFixTable = this.isInFixedTable(key) || !!fixed;
                    titleDOM = (React.createElement(Dropdown, __assign({}, other, { withInput: false, onChange: function (val) {
                            var _a;
                            var emitVal = (_a = {},
                                _a[ref_1] = val,
                                _a);
                            Call(onChange_1, emitVal);
                            Call(_this.props.onChange, emitVal, title);
                        }, scrollX: isInFixTable ? 0 : this.scrollX, 
                        // scrollY={this.scrollY}
                        outside: outside, defaultTitle: defaultTitle, invalidTip: invalidTip, cancelTitle: cancelTitle })));
                    if (this.sortIgnores.indexOf(key) === -1)
                        this.sortIgnores.push(key);
                    break;
            }
        }
        else {
            titleDOM = this.$T(title || key);
        }
        var tipsDOM = tips ? (React.createElement(ToolTip, { n: "question", s: "r", title: tips })) : null;
        return (React.createElement("div", null,
            tipsDOM,
            titleDOM));
    };
    return MapperFilter;
}(UkeComponent));
export default MapperFilter;
export { excludeKey };
